pub struct UnsignedDecimal(Decimal);Tuple Fields
0: DecimalImplementations
Sourceimpl UnsignedDecimal
impl UnsignedDecimal
Sourcepub fn new(value: Decimal) -> Result<Self, O2Error>
pub fn new(value: Decimal) -> Result<Self, O2Error>
Create a new UnsignedDecimal, returning an error if the value is negative.
Sourcepub fn try_sub(&self, other: Self) -> Result<Self, O2Error>
pub fn try_sub(&self, other: Self) -> Result<Self, O2Error>
Fallible subtraction — returns an error if the result would be negative.
Sourcepub fn into_inner(self) -> Decimal
pub fn into_inner(self) -> Decimal
Consume and return the inner Decimal.