pub struct DepthSnapshot {
pub bids: Vec<DepthLevel>,
pub asks: Vec<DepthLevel>,
}Expand description
Depth snapshot from GET /v1/depth or WebSocket subscribe_depth.
Fields
bids: Vec<DepthLevel>Bid side of the order book, sorted by price descending.
asks: Vec<DepthLevel>Ask side of the order book, sorted by price ascending.