format_error

Function format_error 

fn format_error(enum_name: &str, variant: &str, description: &str) -> String
Format a decoded error into the standard output string.

Output: EnumShortName::Variant — description

The short name is the last segment of the fully-qualified enum name (e.g. contract_schema::order_book::OrderCreationError -> OrderCreationError).