#[non_exhaustive]pub enum O2Error {
Show 36 variants
InternalError(String),
InvalidRequest(String),
ParseError(String),
RateLimitExceeded(String),
GeoRestricted(String),
MarketNotFound(String),
MarketPaused(String),
MarketAlreadyExists(String),
OrderNotFound(String),
OrderNotActive(String),
InvalidOrderParams(String),
InvalidSignature(String),
InvalidSession(String),
AccountNotFound(String),
WhitelistNotConfigured(String),
TradeNotFound(String),
InvalidTradeCount(String),
AlreadySubscribed(String),
TooManySubscriptions(String),
SubscriptionError(String),
InvalidAmount(String),
InvalidTimeRange(String),
InvalidPagination(String),
NoActionsProvided(String),
TooManyActions(String),
BlockNotFound(String),
EventsNotFound(String),
OnChainRevert {
message: String,
reason: String,
receipts: Option<Value>,
},
SessionExpired(String),
HttpError(String),
WebSocketError(String),
WebSocketReconnected,
WebSocketDisconnected(String),
JsonError(String),
CryptoError(String),
Other(String),
}Expand description
The primary error type for the O2 SDK.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InternalError(String)
InvalidRequest(String)
ParseError(String)
RateLimitExceeded(String)
GeoRestricted(String)
MarketNotFound(String)
MarketPaused(String)
MarketAlreadyExists(String)
OrderNotFound(String)
OrderNotActive(String)
InvalidOrderParams(String)
InvalidSignature(String)
InvalidSession(String)
AccountNotFound(String)
WhitelistNotConfigured(String)
TradeNotFound(String)
InvalidTradeCount(String)
AlreadySubscribed(String)
TooManySubscriptions(String)
SubscriptionError(String)
InvalidAmount(String)
InvalidTimeRange(String)
InvalidPagination(String)
NoActionsProvided(String)
TooManyActions(String)
BlockNotFound(String)
EventsNotFound(String)
OnChainRevert
SessionExpired(String)
HttpError(String)
WebSocketError(String)
WebSocketReconnected
WebSocketDisconnected(String)
JsonError(String)
CryptoError(String)
Other(String)
Implementations
Sourceimpl O2Error
impl O2Error
Sourcepub fn from_code(code: u32, message: String) -> Self
pub fn from_code(code: u32, message: String) -> Self
Create an O2Error from an API error code and message.
Sourcepub fn error_code(&self) -> Option<u32>
pub fn error_code(&self) -> Option<u32>
Returns the error code if this is a coded API error.
Sourcepub fn is_retryable(&self) -> bool
pub fn is_retryable(&self) -> bool
Returns true if this error suggests retrying with backoff.